import React from 'react';
import './Filter.css';
import ValuesFilter from './ValuesFilter.js';
import TimeFilter from './TimeFilter.js';

class Filter extends React.Component {

  constructor(props) {
    super(props);
    this.state = {
      facets: {}
    };
    this.time = {
      timeFrom: '1900-01-01T00:00:00Z',
      timeTo: 'NOW'
    }
    this.filterObject = {};
  }

  handleValuesFilterChange(field, values) {

    if (values && values.length > 0) {
      this.filterObject[field] = '(' + values.map(v => `+"${v}"`).join(" ") + ')';
    } else {
      delete this.filterObject[field];
    }

    this.props.onChange(this.filterObject);
  }

  handleTimeFilterChange(field, timeFrom, timeTo) {
    this.setFilter({ filterT: field, filterS: '[' + timeFrom + ' TO ' + timeTo + ']' });
  }

  setFilter = (data) => {
    this.filterObject[data.filterT] = data.filterS;
    this.props.onChange(this.filterObject);
  }

  render() {
    let searchData = this.props.searchData.docs || [];

    let groups = this.props.facets.group_name_s || [];
    groups = groups.filter(l => l.count > 0); 

    let languages = this.props.facets.extra_Language || [];
    languages = languages.filter(l => l.count > 0); 

    let tags = this.props.facets.tags_ss || [];
    tags = tags.filter(l => l.count > 0); 

    let authors = this.props.facets.author_ss || [];
    authors = authors.filter(l => l.count > 0); 

    if (searchData.length === 0) {
      return (
        <div>
          No results found yet.
        </div>
      );
    }

    return (
      <div className="all-filters">

        <TimeFilter title="Publication Time" 
          onChange = {(timeFrom, timeTo) => this.handleTimeFilterChange('extra_PublicationTimestamp', timeFrom, timeTo)} />

        <ValuesFilter title="Author" values={authors} onChange={(values) => this.handleValuesFilterChange('author_ss', values)} />

        <ValuesFilter title="Language" values={languages} onChange={(values) => this.handleValuesFilterChange('extra_Language', values)} />

        <ValuesFilter title="Research Group" values={groups} onChange={(values) => this.handleValuesFilterChange('group_name_s', values)} />

        <ValuesFilter title="Tag" values={tags} onChange={(values) => this.handleValuesFilterChange('tags_ss', values)} />

      </div>
      )
  }
}

export default Filter;

// vi: ft=javascript.jsx
