import React from 'react';
import './SearchResult.css';
import ResultClustering from '../result-clustering/ResultClustering';
import Paper from 'material-ui/Paper';
import AppBar from 'material-ui/AppBar';
import Tabs, { Tab } from 'material-ui/Tabs';
import Truncate from 'react-truncate';
import ReactPaginate from 'react-paginate';
import _ from 'lodash';

/**
 * Zuständig für die Abfragen, das Anzeigen sowie
 * die Pagination der Suchergebnisse
 */
class SearchResult extends React.Component {

  constructor(props) {
    super(props);
    this.rows =  10;
    this.state = {
      currentTab: 0,
      currentPage: 1,
      loading: false
    };
  }

  handlePageChange(page) {
    this.setState({currentPage: page + 1});
    this.props.onPageChange(page);
  }

  render() {
    let docs = this.props.searchData.docs;
    let numFound = this.props.searchData.numFound;
    let pageCount = numFound / this.rows;
    if (numFound > this.rows && numFound % this.rows !== 0) {
      pageCount += 1;
    }
    if (numFound === 0) {
      return (
        <div>
          No results found yet.
        </div>
      );
    }

    let resultList = null;
    if (this.state.loading) {
      resultList = <p>Fetching results ...</p>;
    } else {
      resultList = docs.map((doc, idx) =>  {
        let notes = doc.notes_s ? doc.notes_s : "No description.";
        let authors = doc.author_ss ? doc.author_ss.split(";").join(", ") : "Unknown authors";
        let languages = doc.extra_Language ? doc.extra_Language.split(";").join(", ") : "Unknown";
        let group = doc.group_name_s;
        let tags = doc.tags_ss ? doc.tags_ss.split(";").join(", ") : 'None';
        let pubTime = doc.extra_PublicationTimestamp ? (new Date(doc.extra_PublicationTimestamp)).toLocaleDateString() : 'Unknown';
        return <div key={idx} className="result">
          <a href={doc.url_s} target="_blank">{doc.title_s}</a>
          <p className="doc-authors">by {authors}</p>
          <p className="doc-other-info">Language: {languages} | Group: {_.startCase(group)} | Tags: {tags} | Published on {pubTime}</p>
          <p>
            <Truncate lines={3}>{notes}</Truncate>
          </p>
        </div>
      });
    }

    let resultTab = <Paper elevation={1} className="result-box">
      <div className="pull-right">Page {this.state.currentPage} of {numFound} results.</div>
      <div className="clear"></div>

      {resultList}

      <ReactPaginate previousLabel={<i className="material-icons">keyboard_arrow_left</i>}
        nextLabel={<i className="material-icons">keyboard_arrow_right</i>}
        breakLabel={"..."}
        breakClassName={"break-me"}
        pageCount={pageCount}
        marginPagesDisplayed={2}
        pageRangeDisplayed={5}
        onPageChange={(page) => this.handlePageChange(page.selected)}
        containerClassName={"component-pagination"}
        pageClassName="pagination-number"
        activeClassName={"active"} />
    </Paper>

    let handleTabChange = (e,currentTab) => {
      this.setState({ currentTab });
    };

    const { currentTab } = this.state;

    return (
      <div>
        <AppBar position="static" className="search-result-appbar">
          <Tabs value={currentTab}
            className="search-result-tabs"
            textColor="primary"
            onChange={handleTabChange}>
            <Tab label="Search results" />
            <Tab label="Results clustering" />
          </Tabs>
        </AppBar>
        {currentTab === 0 && resultTab }
        {currentTab === 1 && <ResultClustering clusters={this.props.searchData.clusters} />}
        {currentTab === 2 && <p>Statistics</p>}
      </div>
    );
  }
}

export default SearchResult;

// vi: ft=javascript.jsx
