## Konzepten

**Schema** legt fest, wie die Daten aus der Datenquellen in Solr indiziert werden. Es definiert u.a. die Felder bzw. die Typen der Felder - also wie die Daten interpretiert werden sollen. Außerdem lassen sich Datentransformationen vor der Indizierung durchführen, was ebenfalls im Schema definiert sind.

> Solr’s schema is a single file (in XML) that stores the details about the fields and field types Solr is expected to understand. The schema defines not only the field or field type names, but also any modifications that should happen to a field before it is indexed. For example, if you want to ensure that a user who enters "abc" and a user who enters "ABC" can both find a document containing the term "ABC", you will want to normalize (lower-case it, in this case) "ABC" when it is indexed, and normalize the user query to be sure of a match. These rules are defined in your schema.
>
> Earlier in the tutorial we mentioned copy fields, which are fields made up of data that originated from other fields. You can also define dynamic fields, which use wildcards (such as `*_t` or `*_s`) to dynamically create fields of a specific field type. These types of rules are also defined in the schema. [Solr Tutorial](https://lucene.apache.org/solr/guide/7_2/solr-tutorial.html)

**RequestHandler**

> A *request handler* processes requests coming to Solr. These might be query requests or index update requests. You will likely need several of these defined, depending on how you want Solr to handle the various requests you will make.

**SearchComponent**

> A *search component* is a feature of search, such as highlighting or faceting. The search component is defined in `solrconfig.xml` separate from the request handlers, and then registered with a request handler as needed.

## Indizierung der Daten

Aus der Daten von Andrej sind 896886 Datensätze importiert.
Wir habe die Konfiguration von Andrej übernehmen und angepasst. 

## Suchen der Daten

Mit einfachen Stichwörten wie z.B. climate, IPCC, … werden jedoch keine Ergebnisse zurückgeliefert.

Zunächst probieren wir die mit Solr mit gelieferten Sample-Daten aus (Film-Daten).

Grund dafür: es fehlt **"cachall" field**. Man muss es vor der Indizierung ins Schema hinzufügen:

```
curl -X POST -H 'Content-type:application/json' --data-binary '{"add-copy-field" : {"source":"*","dest":"_text_"}}' http://localhost:8983/solr/<core-name>/schema
```

## Probleme bei der Implementierung

Bei der Implementation von Pagination, solr stürtz ab, wenn man mit einem höheren "start"-Parameter etwa 17

```
From Solr-Log Datei:
# java.lang.OutOfMemoryError: Java heap space
# -XX:OnOutOfMemoryError="/Users/ngnmhieu/Work/Projects/BigData/solr-7.1.0/bin/oom_solr.sh 8983 /Users/ngnmhieu/Work/Projects/BigData/solr-7.1.0/server/logs"
#   Executing "/Users/ngnmhieu/Work/Projects/BigData/solr-7.1.0/bin/oom_solr.sh 8983 /Users/ngnmhieu/Work/Projects/BigData/solr-7.1.0/server/logs"...
```

### Ausprobieren von Carrot2

Installation und Konfiguration siehe [Link](https://lucene.apache.org/solr/guide/6_6/result-clustering.html#ResultClustering-DeclarationoftheSearchComponentandRequestHandler). 

Visualisierung von Carrot2 Clustering Ergebnisse mit FoamTree: eigene HTML-Seite, embedded in React-App mit iframe

Aktuelle Zustand: Einfache Darstellung von den Clusters.

Mögliche zukünftige Erweiterungen:

- hierarchische Darstellung von den Clustern.
- andere Darstellungsmöglichkeiten

## Festes Schema aus managed-schema

Bei einigen Feldern ist custom-parsing nötig wie z.B. authors oder tags. Solr kann dabei die Elemente der Liste nicht extrahieren.

Zusammenhängend: Implementation von Filtern, von Eike übernommen

### Extra_* Felder generieren

